geoh5py: Python API for geoh5. An open file format for geoscientific data
==========================================================================

The **geoh5py** library has been created for the manipulation and storage of a wide range of
geoscientific data (points, curve, surface, 2D and 3D grids) in
`geoh5 file format <https://gist.github.com/jincandescent/06a3bd4e0e54360ad191>`_.
Users will be able to directly leverage the powerful visualization
capabilities of `Geoscience ANALYST <https://mirageoscience.com/mining-industry-software/geoscience-analyst/>`_ along with open-source code from the Python ecosystem.

Installation
^^^^^^^^^^^^
**geoh5py** is currently written for Python 3.7 or higher, and depends on `NumPy <https://numpy.org/>`_ and
`h5py <https://www.h5py.org/>`_.

.. note:: Users will likely want to take advantage of other packages available in the Python ecosystem.
    We therefore recommend using `Anaconda <https://www.anaconda.com/download/>`_ to manage the installation.


Install **geoh5py** from PyPI::

    $ pip install geoh5py


Feedback
^^^^^^^^
Have comments or suggestions? Submit feedback.
All the content can be found on the github_ repository.

.. _github: https://github.com/MiraGeoscience/geoh5py


Visit `Mira Geoscience website <https://mirageoscience.com/>`_ to learn more about our products
and services.


License
^^^^^^^
geoh5py is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

geoh5py is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with geoh5py.  If not, see <https://www.gnu.org/licenses/>.


Copyright
^^^^^^^^^
Copyright (c) 2023 Mira Geoscience Ltd.
